# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #


class SettingConstants:

    """
    Accel.
    """
    ACCEL = "accel"

    """
    Calibration Type.
    """
    CALIBRATION_TYPE = "calibration.type"

    """
    Cloop Continuous Enable.
    """
    CLOOP_CONTINUOUS_ENABLE = "cloop.continuous.enable"

    """
    Cloop Counts.
    """
    CLOOP_COUNTS = "cloop.counts"

    """
    Cloop Displace Tolerance.
    """
    CLOOP_DISPLACE_TOLERANCE = "cloop.displace.tolerance"

    """
    Cloop Duration Max.
    """
    CLOOP_DURATION_MAX = "cloop.duration.max"

    """
    Cloop Enable.
    """
    CLOOP_ENABLE = "cloop.enable"

    """
    Cloop Mode.
    """
    CLOOP_MODE = "cloop.mode"

    """
    Cloop Recovery Enable.
    """
    CLOOP_RECOVERY_ENABLE = "cloop.recovery.enable"

    """
    Cloop Servo Enable.
    """
    CLOOP_SERVO_ENABLE = "cloop.servo.enable"

    """
    Cloop Settle Period.
    """
    CLOOP_SETTLE_PERIOD = "cloop.settle.period"

    """
    Cloop Settle Tolerance.
    """
    CLOOP_SETTLE_TOLERANCE = "cloop.settle.tolerance"

    """
    Cloop Stalltimeout.
    """
    CLOOP_STALLTIMEOUT = "cloop.stalltimeout"

    """
    Cloop Steps.
    """
    CLOOP_STEPS = "cloop.steps"

    """
    Cloop Timeout.
    """
    CLOOP_TIMEOUT = "cloop.timeout"

    """
    Comm Address.
    """
    COMM_ADDRESS = "comm.address"

    """
    Comm Alert.
    """
    COMM_ALERT = "comm.alert"

    """
    Comm Checksum.
    """
    COMM_CHECKSUM = "comm.checksum"

    """
    Comm En Ipv 4 Address.
    """
    COMM_EN_IPV_4_ADDRESS = "comm.en.ipv4.address"

    """
    Comm En Ipv 4 Dhcp Enabled.
    """
    COMM_EN_IPV_4_DHCP_ENABLED = "comm.en.ipv4.dhcp.enabled"

    """
    Comm En Ipv 4 Gateway.
    """
    COMM_EN_IPV_4_GATEWAY = "comm.en.ipv4.gateway"

    """
    Comm En Ipv 4 Netmask.
    """
    COMM_EN_IPV_4_NETMASK = "comm.en.ipv4.netmask"

    """
    Comm En Mdns Enable.
    """
    COMM_EN_MDNS_ENABLE = "comm.en.mdns.enable"

    """
    Comm Protocol.
    """
    COMM_PROTOCOL = "comm.protocol"

    """
    Comm Rs 232 Baud.
    """
    COMM_RS_232_BAUD = "comm.rs232.baud"

    """
    Comm Rs 232 Protocol.
    """
    COMM_RS_232_PROTOCOL = "comm.rs232.protocol"

    """
    Comm Rs 485 Baud.
    """
    COMM_RS_485_BAUD = "comm.rs485.baud"

    """
    Comm Rs 485 Enable.
    """
    COMM_RS_485_ENABLE = "comm.rs485.enable"

    """
    Comm Rs 485 Protocol.
    """
    COMM_RS_485_PROTOCOL = "comm.rs485.protocol"

    """
    Comm Usb Protocol.
    """
    COMM_USB_PROTOCOL = "comm.usb.protocol"

    """
    Device Hw Modified.
    """
    DEVICE_HW_MODIFIED = "device.hw.modified"

    """
    Deviceid.
    """
    DEVICEID = "deviceid"

    """
    Driver Current Hold.
    """
    DRIVER_CURRENT_HOLD = "driver.current.hold"

    """
    Driver Current Max.
    """
    DRIVER_CURRENT_MAX = "driver.current.max"

    """
    Driver Current Run.
    """
    DRIVER_CURRENT_RUN = "driver.current.run"

    """
    Driver Current Servo.
    """
    DRIVER_CURRENT_SERVO = "driver.current.servo"

    """
    Driver Dir.
    """
    DRIVER_DIR = "driver.dir"

    """
    Driver Enabled.
    """
    DRIVER_ENABLED = "driver.enabled"

    """
    Driver Temperature.
    """
    DRIVER_TEMPERATURE = "driver.temperature"

    """
    Encoder 1 Count.
    """
    ENCODER_1_COUNT = "encoder.1.count"

    """
    Encoder 1 Count Cal.
    """
    ENCODER_1_COUNT_CAL = "encoder.1.count.cal"

    """
    Encoder 1 Dir.
    """
    ENCODER_1_DIR = "encoder.1.dir"

    """
    Encoder 1 Fault Type.
    """
    ENCODER_1_FAULT_TYPE = "encoder.1.fault.type"

    """
    Encoder 1 Filter.
    """
    ENCODER_1_FILTER = "encoder.1.filter"

    """
    Encoder 1 Index Mode.
    """
    ENCODER_1_INDEX_MODE = "encoder.1.index.mode"

    """
    Encoder 1 Mode.
    """
    ENCODER_1_MODE = "encoder.1.mode"

    """
    Encoder 1 Pos.
    """
    ENCODER_1_POS = "encoder.1.pos"

    """
    Encoder 1 Pos Error.
    """
    ENCODER_1_POS_ERROR = "encoder.1.pos.error"

    """
    Encoder 1 Ratio Div.
    """
    ENCODER_1_RATIO_DIV = "encoder.1.ratio.div"

    """
    Encoder 1 Ratio Mult.
    """
    ENCODER_1_RATIO_MULT = "encoder.1.ratio.mult"

    """
    Encoder 1 Ref Phase.
    """
    ENCODER_1_REF_PHASE = "encoder.1.ref.phase"

    """
    Encoder 1 Type.
    """
    ENCODER_1_TYPE = "encoder.1.type"

    """
    Encoder 2 Cos.
    """
    ENCODER_2_COS = "encoder.2.cos"

    """
    Encoder 2 Cos Dc.
    """
    ENCODER_2_COS_DC = "encoder.2.cos.dc"

    """
    Encoder 2 Cos Dc Tune.
    """
    ENCODER_2_COS_DC_TUNE = "encoder.2.cos.dc.tune"

    """
    Encoder 2 Cos Gain.
    """
    ENCODER_2_COS_GAIN = "encoder.2.cos.gain"

    """
    Encoder 2 Cos Gain Tune.
    """
    ENCODER_2_COS_GAIN_TUNE = "encoder.2.cos.gain.tune"

    """
    Encoder 2 Count.
    """
    ENCODER_2_COUNT = "encoder.2.count"

    """
    Encoder 2 Count Cal.
    """
    ENCODER_2_COUNT_CAL = "encoder.2.count.cal"

    """
    Encoder 2 Dir.
    """
    ENCODER_2_DIR = "encoder.2.dir"

    """
    Encoder 2 Fault Type.
    """
    ENCODER_2_FAULT_TYPE = "encoder.2.fault.type"

    """
    Encoder 2 Filter.
    """
    ENCODER_2_FILTER = "encoder.2.filter"

    """
    Encoder 2 Index Mode.
    """
    ENCODER_2_INDEX_MODE = "encoder.2.index.mode"

    """
    Encoder 2 Interpolation.
    """
    ENCODER_2_INTERPOLATION = "encoder.2.interpolation"

    """
    Encoder 2 Mode.
    """
    ENCODER_2_MODE = "encoder.2.mode"

    """
    Encoder 2 Pos.
    """
    ENCODER_2_POS = "encoder.2.pos"

    """
    Encoder 2 Pos Error.
    """
    ENCODER_2_POS_ERROR = "encoder.2.pos.error"

    """
    Encoder 2 Ratio Div.
    """
    ENCODER_2_RATIO_DIV = "encoder.2.ratio.div"

    """
    Encoder 2 Ratio Mult.
    """
    ENCODER_2_RATIO_MULT = "encoder.2.ratio.mult"

    """
    Encoder 2 Signal Min.
    """
    ENCODER_2_SIGNAL_MIN = "encoder.2.signal.min"

    """
    Encoder 2 Sin.
    """
    ENCODER_2_SIN = "encoder.2.sin"

    """
    Encoder 2 Sin Dc.
    """
    ENCODER_2_SIN_DC = "encoder.2.sin.dc"

    """
    Encoder 2 Sin Dc Tune.
    """
    ENCODER_2_SIN_DC_TUNE = "encoder.2.sin.dc.tune"

    """
    Encoder 2 Sin Gain.
    """
    ENCODER_2_SIN_GAIN = "encoder.2.sin.gain"

    """
    Encoder 2 Sin Gain Tune.
    """
    ENCODER_2_SIN_GAIN_TUNE = "encoder.2.sin.gain.tune"

    """
    Encoder 2 Type.
    """
    ENCODER_2_TYPE = "encoder.2.type"

    """
    Encoder Count.
    """
    ENCODER_COUNT = "encoder.count"

    """
    Encoder Count Cal.
    """
    ENCODER_COUNT_CAL = "encoder.count.cal"

    """
    Encoder Count Calibrated.
    """
    ENCODER_COUNT_CALIBRATED = "encoder.count.calibrated"

    """
    Encoder Dir.
    """
    ENCODER_DIR = "encoder.dir"

    """
    Encoder Error.
    """
    ENCODER_ERROR = "encoder.error"

    """
    Encoder Fault Type.
    """
    ENCODER_FAULT_TYPE = "encoder.fault.type"

    """
    Encoder Filter.
    """
    ENCODER_FILTER = "encoder.filter"

    """
    Encoder Index Count.
    """
    ENCODER_INDEX_COUNT = "encoder.index.count"

    """
    Encoder Index Mode.
    """
    ENCODER_INDEX_MODE = "encoder.index.mode"

    """
    Encoder Index Phase.
    """
    ENCODER_INDEX_PHASE = "encoder.index.phase"

    """
    Encoder Mode.
    """
    ENCODER_MODE = "encoder.mode"

    """
    Encoder Port Default.
    """
    ENCODER_PORT_DEFAULT = "encoder.port.default"

    """
    Encoder Pos.
    """
    ENCODER_POS = "encoder.pos"

    """
    Encoder Pos Error.
    """
    ENCODER_POS_ERROR = "encoder.pos.error"

    """
    Encoder Ratio Div.
    """
    ENCODER_RATIO_DIV = "encoder.ratio.div"

    """
    Encoder Ratio Mult.
    """
    ENCODER_RATIO_MULT = "encoder.ratio.mult"

    """
    Filter Holderid.
    """
    FILTER_HOLDERID = "filter.holderid"

    """
    Force Average.
    """
    FORCE_AVERAGE = "force.average"

    """
    Io Di Port.
    """
    IO_DI_PORT = "io.di.port"

    """
    Io Do Port.
    """
    IO_DO_PORT = "io.do.port"

    """
    Joy Debug.
    """
    JOY_DEBUG = "joy.debug"

    """
    Knob Dir.
    """
    KNOB_DIR = "knob.dir"

    """
    Knob Distance.
    """
    KNOB_DISTANCE = "knob.distance"

    """
    Knob Enable.
    """
    KNOB_ENABLE = "knob.enable"

    """
    Knob Force.
    """
    KNOB_FORCE = "knob.force"

    """
    Knob Forceprofile.
    """
    KNOB_FORCEPROFILE = "knob.forceprofile"

    """
    Knob Maxspeed.
    """
    KNOB_MAXSPEED = "knob.maxspeed"

    """
    Knob Mode.
    """
    KNOB_MODE = "knob.mode"

    """
    Knob Speedprofile.
    """
    KNOB_SPEEDPROFILE = "knob.speedprofile"

    """
    Lamp Current.
    """
    LAMP_CURRENT = "lamp.current"

    """
    Lamp Current Max.
    """
    LAMP_CURRENT_MAX = "lamp.current.max"

    """
    Lamp Flux.
    """
    LAMP_FLUX = "lamp.flux"

    """
    Lamp Flux Max.
    """
    LAMP_FLUX_MAX = "lamp.flux.max"

    """
    Lamp Status.
    """
    LAMP_STATUS = "lamp.status"

    """
    Lamp Temperature.
    """
    LAMP_TEMPERATURE = "lamp.temperature"

    """
    Lamp Wavelength Fwhm.
    """
    LAMP_WAVELENGTH_FWHM = "lamp.wavelength.fwhm"

    """
    Lamp Wavelength Peak.
    """
    LAMP_WAVELENGTH_PEAK = "lamp.wavelength.peak"

    """
    Limit Approach Accel.
    """
    LIMIT_APPROACH_ACCEL = "limit.approach.accel"

    """
    Limit Approach Maxspeed.
    """
    LIMIT_APPROACH_MAXSPEED = "limit.approach.maxspeed"

    """
    Limit Away Action.
    """
    LIMIT_AWAY_ACTION = "limit.away.action"

    """
    Limit Away Edge.
    """
    LIMIT_AWAY_EDGE = "limit.away.edge"

    """
    Limit Away Pos.
    """
    LIMIT_AWAY_POS = "limit.away.pos"

    """
    Limit Away Posupdate.
    """
    LIMIT_AWAY_POSUPDATE = "limit.away.posupdate"

    """
    Limit Away Preset.
    """
    LIMIT_AWAY_PRESET = "limit.away.preset"

    """
    Limit Away Source.
    """
    LIMIT_AWAY_SOURCE = "limit.away.source"

    """
    Limit Away State.
    """
    LIMIT_AWAY_STATE = "limit.away.state"

    """
    Limit Away Triggered.
    """
    LIMIT_AWAY_TRIGGERED = "limit.away.triggered"

    """
    Limit Away Tune.
    """
    LIMIT_AWAY_TUNE = "limit.away.tune"

    """
    Limit Away Type.
    """
    LIMIT_AWAY_TYPE = "limit.away.type"

    """
    Limit Away Width.
    """
    LIMIT_AWAY_WIDTH = "limit.away.width"

    """
    Limit C Action.
    """
    LIMIT_C_ACTION = "limit.c.action"

    """
    Limit C Edge.
    """
    LIMIT_C_EDGE = "limit.c.edge"

    """
    Limit C Pos.
    """
    LIMIT_C_POS = "limit.c.pos"

    """
    Limit C Posupdate.
    """
    LIMIT_C_POSUPDATE = "limit.c.posupdate"

    """
    Limit C Preset.
    """
    LIMIT_C_PRESET = "limit.c.preset"

    """
    Limit C Source.
    """
    LIMIT_C_SOURCE = "limit.c.source"

    """
    Limit C State.
    """
    LIMIT_C_STATE = "limit.c.state"

    """
    Limit C Triggered.
    """
    LIMIT_C_TRIGGERED = "limit.c.triggered"

    """
    Limit C Tune.
    """
    LIMIT_C_TUNE = "limit.c.tune"

    """
    Limit C Type.
    """
    LIMIT_C_TYPE = "limit.c.type"

    """
    Limit C Width.
    """
    LIMIT_C_WIDTH = "limit.c.width"

    """
    Limit Cycle Dist.
    """
    LIMIT_CYCLE_DIST = "limit.cycle.dist"

    """
    Limit D Action.
    """
    LIMIT_D_ACTION = "limit.d.action"

    """
    Limit D Edge.
    """
    LIMIT_D_EDGE = "limit.d.edge"

    """
    Limit D Pos.
    """
    LIMIT_D_POS = "limit.d.pos"

    """
    Limit D Posupdate.
    """
    LIMIT_D_POSUPDATE = "limit.d.posupdate"

    """
    Limit D Preset.
    """
    LIMIT_D_PRESET = "limit.d.preset"

    """
    Limit D State.
    """
    LIMIT_D_STATE = "limit.d.state"

    """
    Limit D Triggered.
    """
    LIMIT_D_TRIGGERED = "limit.d.triggered"

    """
    Limit D Type.
    """
    LIMIT_D_TYPE = "limit.d.type"

    """
    Limit Detect Decelonly.
    """
    LIMIT_DETECT_DECELONLY = "limit.detect.decelonly"

    """
    Limit Detect Maxspeed.
    """
    LIMIT_DETECT_MAXSPEED = "limit.detect.maxspeed"

    """
    Limit Home Action.
    """
    LIMIT_HOME_ACTION = "limit.home.action"

    """
    Limit Home Bidirectional.
    """
    LIMIT_HOME_BIDIRECTIONAL = "limit.home.bidirectional"

    """
    Limit Home Edge.
    """
    LIMIT_HOME_EDGE = "limit.home.edge"

    """
    Limit Home Pos.
    """
    LIMIT_HOME_POS = "limit.home.pos"

    """
    Limit Home Posupdate.
    """
    LIMIT_HOME_POSUPDATE = "limit.home.posupdate"

    """
    Limit Home Preset.
    """
    LIMIT_HOME_PRESET = "limit.home.preset"

    """
    Limit Home Source.
    """
    LIMIT_HOME_SOURCE = "limit.home.source"

    """
    Limit Home State.
    """
    LIMIT_HOME_STATE = "limit.home.state"

    """
    Limit Home Triggered.
    """
    LIMIT_HOME_TRIGGERED = "limit.home.triggered"

    """
    Limit Home Tune.
    """
    LIMIT_HOME_TUNE = "limit.home.tune"

    """
    Limit Home Type.
    """
    LIMIT_HOME_TYPE = "limit.home.type"

    """
    Limit Home Width.
    """
    LIMIT_HOME_WIDTH = "limit.home.width"

    """
    Limit Max.
    """
    LIMIT_MAX = "limit.max"

    """
    Limit Min.
    """
    LIMIT_MIN = "limit.min"

    """
    Limit Range Mode.
    """
    LIMIT_RANGE_MODE = "limit.range.mode"

    """
    Limit Ref Phase.
    """
    LIMIT_REF_PHASE = "limit.ref.phase"

    """
    Limit Ref Phase Measured.
    """
    LIMIT_REF_PHASE_MEASURED = "limit.ref.phase.measured"

    """
    Limit Start Pos.
    """
    LIMIT_START_POS = "limit.start.pos"

    """
    Limit Swapinputs.
    """
    LIMIT_SWAPINPUTS = "limit.swapinputs"

    """
    Lockstep Numgroups.
    """
    LOCKSTEP_NUMGROUPS = "lockstep.numgroups"

    """
    Lockstep Tolerance.
    """
    LOCKSTEP_TOLERANCE = "lockstep.tolerance"

    """
    Maxspeed.
    """
    MAXSPEED = "maxspeed"

    """
    Motion Accel Ramptime.
    """
    MOTION_ACCEL_RAMPTIME = "motion.accel.ramptime"

    """
    Motion Accelonly.
    """
    MOTION_ACCELONLY = "motion.accelonly"

    """
    Motion Busy.
    """
    MOTION_BUSY = "motion.busy"

    """
    Motion Decelonly.
    """
    MOTION_DECELONLY = "motion.decelonly"

    """
    Motion Index Dist.
    """
    MOTION_INDEX_DIST = "motion.index.dist"

    """
    Motion Index Num.
    """
    MOTION_INDEX_NUM = "motion.index.num"

    """
    Motor Current Max.
    """
    MOTOR_CURRENT_MAX = "motor.current.max"

    """
    Motor Inductance.
    """
    MOTOR_INDUCTANCE = "motor.inductance"

    """
    Motor Phase.
    """
    MOTOR_PHASE = "motor.phase"

    """
    Motor Phase Ratio Div 1.
    """
    MOTOR_PHASE_RATIO_DIV_1 = "motor.phase.ratio.div1"

    """
    Motor Phase Ratio Div 2.
    """
    MOTOR_PHASE_RATIO_DIV_2 = "motor.phase.ratio.div2"

    """
    Motor Phase Ratio Mult.
    """
    MOTOR_PHASE_RATIO_MULT = "motor.phase.ratio.mult"

    """
    Motor Resistance.
    """
    MOTOR_RESISTANCE = "motor.resistance"

    """
    Parking State.
    """
    PARKING_STATE = "parking.state"

    """
    Peripheral Hw Modified.
    """
    PERIPHERAL_HW_MODIFIED = "peripheral.hw.modified"

    """
    Peripheral ID (Firmware 7 and higher).
    """
    PERIPHERAL_ID = "peripheral.id"

    """
    Peripheral Id Pending.
    """
    PERIPHERAL_ID_PENDING = "peripheral.id.pending"

    """
    Peripheral Serial.
    """
    PERIPHERAL_SERIAL = "peripheral.serial"

    """
    Peripheral Serial Pending.
    """
    PERIPHERAL_SERIAL_PENDING = "peripheral.serial.pending"

    """
    Peripheral ID (Firmware 6 and lower).
    """
    PERIPHERALID = "peripheralid"

    """
    Pos.
    """
    POS = "pos"

    """
    Resolution.
    """
    RESOLUTION = "resolution"

    """
    Scope Delay.
    """
    SCOPE_DELAY = "scope.delay"

    """
    Scope Timebase.
    """
    SCOPE_TIMEBASE = "scope.timebase"

    """
    Stream Numbufs.
    """
    STREAM_NUMBUFS = "stream.numbufs"

    """
    Stream Numstreams.
    """
    STREAM_NUMSTREAMS = "stream.numstreams"

    """
    System Access.
    """
    SYSTEM_ACCESS = "system.access"

    """
    System Axiscount.
    """
    SYSTEM_AXISCOUNT = "system.axiscount"

    """
    System Current.
    """
    SYSTEM_CURRENT = "system.current"

    """
    System Led Enable.
    """
    SYSTEM_LED_ENABLE = "system.led.enable"

    """
    System Serial.
    """
    SYSTEM_SERIAL = "system.serial"

    """
    System Temperature.
    """
    SYSTEM_TEMPERATURE = "system.temperature"

    """
    System Voltage.
    """
    SYSTEM_VOLTAGE = "system.voltage"

    """
    Trigger Numactions.
    """
    TRIGGER_NUMACTIONS = "trigger.numactions"

    """
    Trigger Numtriggers.
    """
    TRIGGER_NUMTRIGGERS = "trigger.numtriggers"

    """
    User Data 0.
    """
    USER_DATA_0 = "user.data.0"

    """
    User Data 1.
    """
    USER_DATA_1 = "user.data.1"

    """
    User Data 10.
    """
    USER_DATA_10 = "user.data.10"

    """
    User Data 11.
    """
    USER_DATA_11 = "user.data.11"

    """
    User Data 12.
    """
    USER_DATA_12 = "user.data.12"

    """
    User Data 13.
    """
    USER_DATA_13 = "user.data.13"

    """
    User Data 14.
    """
    USER_DATA_14 = "user.data.14"

    """
    User Data 15.
    """
    USER_DATA_15 = "user.data.15"

    """
    User Data 2.
    """
    USER_DATA_2 = "user.data.2"

    """
    User Data 3.
    """
    USER_DATA_3 = "user.data.3"

    """
    User Data 4.
    """
    USER_DATA_4 = "user.data.4"

    """
    User Data 5.
    """
    USER_DATA_5 = "user.data.5"

    """
    User Data 6.
    """
    USER_DATA_6 = "user.data.6"

    """
    User Data 7.
    """
    USER_DATA_7 = "user.data.7"

    """
    User Data 8.
    """
    USER_DATA_8 = "user.data.8"

    """
    User Data 9.
    """
    USER_DATA_9 = "user.data.9"

    """
    User Vdata 0.
    """
    USER_VDATA_0 = "user.vdata.0"

    """
    User Vdata 1.
    """
    USER_VDATA_1 = "user.vdata.1"

    """
    User Vdata 2.
    """
    USER_VDATA_2 = "user.vdata.2"

    """
    User Vdata 3.
    """
    USER_VDATA_3 = "user.vdata.3"

    """
    Vel.
    """
    VEL = "vel"

    """
    Version.
    """
    VERSION = "version"

    """
    Version Build.
    """
    VERSION_BUILD = "version.build"

    """
    Virtual Numvirtual.
    """
    VIRTUAL_NUMVIRTUAL = "virtual.numvirtual"
